"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildClickSteps = void 0;
const debug_1 = __importDefault(require("debug"));
const target_1 = require("./target");
const debug = debug_1.default('qawolf:buildClickSteps');
const filterClickEvents = (events) => {
    return events.filter((event, i) => {
        // track original event index
        event.index = i;
        // ignore system initiated clicks
        if (!event.isTrusted)
            return false;
        // ignore other actions
        if (!['click', 'mousedown'].includes(event.name))
            return false;
        const previousEvent = events[i - 1];
        if (previousEvent &&
            ['change', 'keydown', 'keyup'].includes(previousEvent.name) &&
            event.time - previousEvent.time < 50) {
            // skip system-initiated clicks triggered by a key press
            // ex. "Enter" triggers a click on a submit input
            debug(`skip click shortly after previous event ${event.time}`);
            return false;
        }
        // ignore clicks on selects
        return event.target.name !== 'select';
    });
};
const groupClickEvents = (events, timeWindow = 200) => {
    const groupedEvents = [];
    let group = [];
    events.forEach((event) => {
        if (!group.length) {
            // first group
            group.push(event);
            return;
        }
        const lastEvent = group[group.length - 1];
        if (event.time - lastEvent.time < timeWindow) {
            // event is within time window
            group.push(event);
            return;
        }
        // start a new group
        groupedEvents.push(group);
        group = [event];
    });
    if (group.length) {
        // append last group
        groupedEvents.push(group);
    }
    return groupedEvents;
};
exports.buildClickSteps = (events) => {
    const clickEvents = filterClickEvents(events);
    const groupedClickEvents = groupClickEvents(clickEvents);
    const steps = [];
    groupedClickEvents.forEach((events) => {
        let event = events[0];
        const inputEvent = events.find((event) => target_1.isInputTarget(event.target));
        if (inputEvent) {
            // if an event in the group is on an  input, assume the click propagated
            // to an element like a checkbox or radio, which is most accurate target
            event = inputEvent;
        }
        steps.push({
            action: 'click',
            index: steps.length,
            event: event,
        });
    });
    return steps;
};
//# sourceMappingURL=buildClickSteps.js.map