"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextEventCollector = void 0;
const debug_1 = __importDefault(require("debug"));
const events_1 = require("events");
const register_1 = require("../utils/context/register");
const debug = debug_1.default('qawolf:ContextEventCollector');
class ContextEventCollector extends events_1.EventEmitter {
    constructor(context) {
        super();
        this._context = context;
    }
    static async create(context) {
        const collector = new ContextEventCollector(context);
        await collector._emitEvents();
        return collector;
    }
    async _emitEvents() {
        if (!register_1.isRegistered(this._context)) {
            throw new Error('Use qawolf.register(context) first');
        }
        await this._context.exposeBinding('qawElementEvent', ({ page }, elementEvent) => {
            const pageIndex = page.createdIndex;
            const event = { ...elementEvent, page: pageIndex };
            debug(`emit %j`, event);
            this.emit('elementevent', event);
        });
    }
}
exports.ContextEventCollector = ContextEventCollector;
//# sourceMappingURL=ContextEventCollector.js.map