import { Cue } from './cues';
declare type IterateCuesOptions = {
    penaltyRangeIncrement?: number;
};
/**
 * @summary Iterates through all possible groups (combinations) of cues, in such an order
 *   as to hopefully provide the best short, readable, and unique selector as quickly as possible.
 * @param {Object[]} cues The list of all cues, in any order.
 * @param {Object} [options] Options
 * @param {Object} [options.penaltyRangeIncrement=5] A higher value means a greater chance
 *   that higher penalty groups are returned before lower penalty groups, but a lower value
 *   potentially does a lot more unnecessary looping. The value must be 1 or greater, and a
 *   value of 1, although slowest, ensures results are 100% sorted in total penalty order.
 *   Values above 1 cause the penalty sorting to be increasingly fuzzy.
 */
export declare function iterateCues(cues: Cue[], options?: IterateCuesOptions): Generator<Cue[], void, undefined>;
export {};
